Wat is OiRA? | OiRA

Thema's

# Wat is OiRA?

## Nieuw bij OiRA?

Hier volgt u een korte inleiding over risicobeoordeling en hoe OiRA u daarbij kan helpen.

## Wat is risicobeoordeling?

Risicobeoordeling is de basis voor succesvol veiligheids- en gezondheidsbeheer en de sleutel tot het terugdringen van arbeidsongevallen en beroepsziekten. Als een risicobeoordeling goed wordt toegepast, kan dit resulteren in een verbetering van de veiligheid en gezondheid op het werk en de bedrijfsprestaties in het algemeen.

De veiligheid en gezondheid van werknemers wordt in Europa beschermd door beoordeling en beheersing van de risico’s op de werkplek. Werkgevers zijn wettelijk verplicht de veiligheid en gezondheid van werknemers op het werk in alle opzichten te waarborgen en een risicobeoordeling uit te voeren. Daarom moeten alle ondernemingen een risicobeoordeling uitvoeren en een actieplan opstellen. Om een doeltreffende risicobeoordeling van de werkplek te kunnen uitvoeren, moeten alle betrokkenen goed bekend zijn met:

- de juridische context en begrippen;
- de procedure die wordt gebruikt om de risico’s te beoordelen;
- de rol van de belangrijkste partijen die bij de procedure zijn betrokken.

Werknemers en/of hun vertegenwoordigers hebben het recht te worden geraadpleegd over regelingen voor uitvoering van en deelname aan risicobeoordelingen.

Meer informatie over risicobeoordeling en deelname van werknemers en/of hun vertegenwoordigers aan de risicobeoordelingsprocedure is te vinden op de website van het OiRA-project.

## Wat is OiRA?

OiRA is een afkorting van Online Interactive Risk Assessment (Online Interactieve Risicobeoordeling). OiRA is een webapplicatie waarmee u een beoordeling van de veiligheids- en gezondheidsrisico’s op uw werkplek kunt uitvoeren.

## Voor wie is OiRA bedoeld?

OiRA kan door iedereen worden gebruikt voor het beoordelen van mogelijke veiligheids- en gezondheidsrisico’s op hun werkplek.

OiRA is echter vooral bedoeld voor kleinere bedrijven. OiRA is speciaal ontwikkeld om hen te ondersteunen bij de beoordeling van risico’s op de werkplek en om hen te helpen met het opstellen van een gedocumenteerde risicobeoordeling, inclusief een actieplan dat is afgestemd op de behoeften van hun bedrijf.

## Wat moet ik doen?

De risicobeoordelingsprocedure van OiRAbestaat uit verschillende stappen:

- Voorbereiding: sommige tools bevatten profielvragen waarmee u de tool kunt afstemmen op de specifieke behoeften van uw bedrijf. Wanneer u de profielvragen beantwoordt, wordt de tool aangepast aan uw specifieke situatie en kunt u zien welke modules er van toepassing zijn.

- Betrokkenheid: elke risicobeoordeling moet worden uitgevoerd met actieve betrokkenheid van de werknemers. Met de tool kunt u de tekst van de risicobeoordeling deels of geheel afdrukken om werknemers te informeren en hun feedback te vernemen.

- Risico-identificatie: OiRA toont een aantal potentiële veiligheids- en gezondheidsrisico’s of -problemen op uw werkplek. Door de stellingen/vragen met ja of nee te beantwoorden, geeft u aan of er bij u op de werkplek sprake is van dergelijke risico’s of problemen. U kunt er ook voor kiezen een vraag onbeantwoord te laten en deze in de wacht te zetten om in een later stadium te beantwoorden.

- Evaluatie: in sommige tools wordt u gevraagd de geïdentificeerde risico’s te prioriteren. Dit kan op verschillende manieren en is afhankelijk van de door onze nationale OiRA-partners/toolontwikkelaars gekozen configuratie en hun specifieke aanpak. In sommige tools worden de risico’s automatisch op de achtergrond geprioriteerd en hebt u de mogelijkheid deze prioriteiten desgewenst niet over te nemen.

- Actieplan: in de tool wordt u voor elk geïdentificeerd risico gevraagd een beslissing te nemen over een of meerdere maatregelen om het risico weg te nemen of te beperken. In de meeste tools wordt een aantal maatregelen voorgesteld. U kunt er ook altijd voor kiezen om uw eigen maatregelen te vermelden.

- Rapport: u bent wettelijk verplicht uw risicobeoordeling te documenteren. In de rubriek Rapport vindt u verschillende rapporten die u kunnen helpen bij het volgen van de ontwikkeling van uw risicobeoordeling en de follow-up van de acties/maatregelen waartoe u hebt besloten om de vastgestelde risico’s weg te nemen of te beperken.

## Hoeveel tijd is er gemoeid met een risicobeoordeling?

Omdat de tools per sector en land verschillen is het onmogelijk te zeggen hoeveel tijd er in het algemeen met een risicobeoordeling gemoeid is.

U kunt echter zoveel tijd als u wilt aan een risicobeoordeling besteden, en wanneer het u uitkomt terugkeren naar de beoordeling om verder te gaan vanaf het punt waar u bent gestopt.

## Waarom moet ik mij inschrijven?

Bij aanvang van uw eerste risicobeoordeling wordt u gevraagd eerst een OiRA-account aan te maken — dit kan eenvoudig en snel.

Als u bent ingeschreven, kunt u op ieder gewenst moment inloggen om uw gegevens in te zien, verder te gaan met eerdere risicobeoordelingen of nieuwe risicobeoordelingen te beginnen.

Als geregistreerde gebruiker hebt u bovendien altijd de mogelijkheid om een accurate en bijgewerkte risicobeoordeling af te drukken.

## Moet ik mij voorbereiden?

Er is geen specifieke voorbereiding vereist voor gebruikmaking van de tool. U moet echter van tevoren beslissen wie de risicobeoordeling gaat uitvoeren en hoe de werknemers bij de beoordeling worden betrokken.

Scroll to top Load toolbar…
Back

## 2-what-is-oira.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More